clc
clear all
close all
% reading input file and setting values for z, S, T
 A=importdata('input_example_dynamic_height.dat');
 B=A.data;
 z = A.data(:,1);
 S = A.data(:,2);
 T = A.data(:,3);
 
 % defining array sizes and constants
 km=size(z,1);
 rho=zeros(km,1); rhoo=zeros(km,1);
 pres=zeros(km,1); delta=zeros(km,1);D=zeros(km,1);
 grav=9.806;
 t0=0.0;s0=35.0;
 
 %calculating density, pressure and density for T=0oC and S=35
 for k=1:km
t1=T(k);s1=S(k);z1=z(k);
rho1 = density(t1,s1,z1); %density=function for equation of state
rho(k)=1000.0+rho1; 
pres(k)=rho(k)*grav*z(k); %pressure in pascal
rho1 = density(t0,s0,z1); %density=function for equation of state
rhoo(k)=1000.0+rho1;
delta(k)=1/rho(k)-1/rhoo(k);
 end
 
 % Dynamic Height calculation --> eq. [4.45]  
 D(km)=0.0;
 for k=km-1:-1:1
 D(k)=D(k+1)+0.5*(delta(k+1)+delta(k))*(pres(k+1)-pres(k));
 end
 
 %saving to output file: fileID=Dynamic_Height_output.dat
 fileID = fopen('Dynamic_Height_output.dat','w');
  formatSpec0 = '%s %s %s %s %s %s\n';
  fprintf(fileID,formatSpec0,'z[m]','S','T[oC]','rho[kg/m^3]','p[Pa]','D[m^2/s^2]');

 formatSpec = '%10.3f %10.3f %10.3f %12.3f %14.3f %10.3f\n';
 for k = 1:km
    fprintf(fileID,formatSpec,z(k),S(k),T(k),rho(k),pres(k),D(k));
end
 fclose(fileID);
 
 
 % Setting plot colors
c1=[0 102 200]/255;%  BLUE
c2=[0 153 51]/255;%  GREEN
c3=[255 102 0]/255;%  ORANGE

 
 lnwidth=2;
 % creating plot for Dynamic Height profile
 figure
 subplot(2,2,1:2)
 plot(D,-z,'-','color',c1,'LineWidth',lnwidth)
 grid on
 axis tight
 xlabel('Dynamic height [m^2/s^2]','interpreter','tex','FontSize',14,'FontWeight','bold');
 ylabel('Depth [m]','FontSize',14,'FontWeight','bold');
 
  subplot(2,2,3)
  plot(S,-z,'-','color',c2,'LineWidth',lnwidth)
  grid on
  axis tight
 xlabel('Salinity','FontSize',12,'FontWeight','bold');
 ylabel('Depth [m]','FontSize',12,'FontWeight','bold');
 
 subplot(2,2,4)
  plot(T,-z,'-','color',c3,'LineWidth',lnwidth)
  grid on
  axis tight
 xlabel('Temperature [^oC]','interpreter','tex','FontSize',12,'FontWeight','bold');
 ylabel('Depth [m]','FontSize',12,'FontWeight','bold');
 

 %Saving file as Dynamic_height_plot.png with 300dpi resolution 
set(gcf,'PaperUnits','centimeters');
xSize = 20; ySize = 20;
xLeft = (21-xSize)/2; yTop = (30-ySize)/2;
set(gcf,'PaperPosition',[xLeft yTop xSize ySize])
print(gcf,'Dynamic_height_plot','-dpng','-r300');